==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/rdf.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

class RDF {
   function export($topic='',$ofile='') {
      global $rdf_lang;
      $CONF = KWL_GetConf();

      if (!empty($ofile)) $this->ofile = "$CONF[G_PATH]/backend/$ofile";
      elseif (empty($CONF['BackendFile'])) $this->ofile = "$CONF[G_PATH]/backend/weblog.rdf";
      else $this->ofile = "$CONF[G_PATH]/backend/$CONF[BackendFile]";

      $sql = "SELECT * FROM T_Stories WHERE Verified = 'Y'";
      if ($topic) $sql .= " AND Topic = $topic";
      $sql .= " ORDER BY Repostamp DESC LIMIT 10";
      $result = SqlReturnArray($sql);
      if (count($result)) {
         
         $this->lang = $rdf_lang;
         $this->write_rdf($result);

         if(function_exists("iconv")) {
            include_once("$CONF[G_PATH]/include/utf8.inc.php");
            $this->lang = "UTF-8";
            $this->ofile .= ".utf";
            $this->write_rdf($result,1);
         }
         
         unset($result);
      }
   }

   function write_rdf($result,$utf=0) {
      global $rdf_lang;
      $CONF = KWL_GetConf();

      if ($utf) {
         $CONF[SiteName] = KWL_ConvertUTF8($rdf_lang,$CONF['SiteName']);
         $CONF[SiteSlogan] = KWL_ConvertUTF8($rdf_lang,$CONF['SiteSlogan']);
      }

      $rdf = "<?xml version=\"1.0\" encoding=\"". $this->lang ."\"?>\n\n".
             "<!DOCTYPE rss PUBLIC \"-//Netscape Communications//DTD RSS 0.91//EN\"\n \"http://my.netscape.com/publish/formats/rss-0.91.dtd\">\n".
             "<rss version=\"0.91\">\n\n".
             "<channel>\n".
             "<title>$CONF[SiteName]</title>\n".
             "<link>$CONF[G_URL]</link>\n".
             "<description>$CONF[SiteSlogan]</description>\n";
          /* "<language>$lang</language>\n\n". */

      foreach ($result as $A) {
         if ($utf) {
            $A['Heading'] = KWL_ConvertUTF8($rdf_lang,$A['Heading']);
            $A['Author'] = KWL_ConvertUTF8($rdf_lang,$A['Author']);
         }
         $rdf .= "<item>\n".
                 "<title>$A[Heading]</title>\n".
                 /* "<author>$A[Author]</author>\n". */
                 "<link>". KWL_MakeStoryLink($A['Rid']) ."</link>\n".
                 "</item>\n\n";
      }
      $rdf .= "</channel>\n</rss>\n";
      if (!KWL_WriteFile($this->ofile,$rdf)) {
         KWL_ErrorLog(_UNABLE_WRITE ." ". $this->ofile);
      }
   }

   function get_rdf($file) {
      $url = @parse_url($file);
      if (isset($url['scheme'])) {
         
         if (!isset($url['port'])) $url['port'] = 80;
         if (!isset($url['query'])) $url['query'] = '';

         $fp = fsockopen($url['host'], 80);
         if ($fp) {
            if (substr(php_uname(), 0, 7) != "Windows") socket_set_timeout($fp, 5);
            fputs($fp, "GET " . $url['path'] . "?" . $url['query'] . " HTTP/1.0\r\n");
            fputs($fp, "HOST: " . $url['host'] . "\r\n\r\n");
            unset($ret);
            $start_at = time();
            $ret = "";
            while(!feof($fp)) {
               $line = fgets($fp, 4096);
               $ret .= trim($line);
               if ((time() - $start_at) == 5) { 
                  /* if we can't retrive file in 5 seconds then give up */
                  return false;
               }
            }
            return $ret;
            fputs($fp,"Connection: close\r\n\r\n");
            fclose($fp);
         } else return false;
      } else {
         /* local file */
         return KWL_ReadFile($file);
      }
   }

   function get_content($file) {
      $url = @parse_url($file);
      if (isset($url['scheme'])) {
         $content = @join ('', @file($file));
         return $content ? $content : false;
      } else {
         /* local file */
         return KWL_ReadFile($file);
      }
   }

   function parse($file,$max_item=10) {
      $dot = KWL_GetConf("dotchar");
      $ret = "";      
      $items = explode("</item>",$file);
      for ($i=0;$i<$max_item;$i++) {
         $link = ereg_replace(".*<link>","",$items[$i]);
         $link = ereg_replace("</link>.*","",$link);
         $title = ereg_replace(".*<title>","",$items[$i]);
         $title = ereg_replace("</title>.*","",$title);
         /*
         $desc = ereg_replace(".*<description>","",$desc[$i]);
         $desc = ereg_replace("</description>.*","",$desc);
         */
         if (strcmp($link,$title)) {
            $trans = get_html_translation_table (HTML_ENTITIES);
            $trans = array_flip ($trans);
            $title = strtr($title, $trans);
            $title = strtr($title, $trans);
            $ret .= $dot ."<a href=\"$link\">". KWL_PrepareHtml($title) ."</a><br>\n";
         }
      }
      return $ret;
   }

   function import($url,$max) {
      return $this->parse($this->get_rdf($url),$max);
   }
} /* end of RDF class */

function KWL_GetContent($A) {
   $file_cache = KWL_GetConf("File_Cache");
   $date       = isset($A['Birthstamp']) ? date("YmdHis",$A['Birthstamp']) : "";
   $updated    = isset($A['Timestamp']) ? date("YmdHis",$A['Timestamp']) : "";
   $time       = date("YmdHis",time());
   $cache      = isset($A['Cache']) ? $A['Cache'] * 60 : "";
   $nextupdate = $updated + $cache;
   $cache_file = isset($A['Rid']) ? md5($A['Rid']) : "";

   if (empty($A['Type'])) return $A['Content'];
   else {

      if ($file_cache && $cache) {
         return KWL_FileCache($A['URL'],$cache,$cache_file,$A['Type'],$A['MaxItem']);
      
      } else {
         
         if ($nextupdate < $time || $date == $updated) {

            if ($A['Type'] == 1) $content = KWL_ImportRdf($A['URL'],$A['MaxItem']);
            else {
               $rdf = new RDF;
               $content = $rdf->get_content($A['URL']);
            }
            if ($A['Cache'] && !empty($content)) {
               $sql 	= "UPDATE T_Blocks SET Content = '". urlencode($content) ."' ".
                       "WHERE Rid = '$A[Rid]'";
               if (!SqlQuery($sql)) KWL_ErrorLog(_UNABLE_RDF);
            }
         
         } else $content = urldecode($A['Content']);
         
         return $content;
      }
   }
}

function KWL_ExportRdf() {
   if (KWL_GetConf("Backend")) {
      $rdf = new RDF;
      $rdf->export();
   }
}

function KWL_ImportRdf($url,$max) {
   $rdf = new RDF;
   return $rdf->import($url,$max);
}

function KWL_FileCache($url,$cache_time,$cache_file,$type=0,$max=10) {
   
	$cache_dir = KWL_GetConf("G_PATH") ."/logs/cache";
   if (!file_exists($cache_dir)) mkdir($cache_dir,0755);
   $cache_file = "$cache_dir/$cache_file".".cache";
   
	$time = split(" ", microtime());
   srand((double)microtime()*1000000);
   $cache_time_rnd = 300 - rand(0, 600);
   $head = "\n<!---- This Block cached at ". date ("m/d h-i a",time()) .
           " ---->\n\n";
   $tail = "\n<!---- End of cached block ---->\n\n";

	clearstatcache();
   if ( (!(file_exists($cache_file))) || ((filectime($cache_file) + $cache_time - $time[1]) + $cache_time_rnd < 0) || (!(filesize($cache_file))) ) {
      
      if ($type == 1) { /* rdf/rss block */
         $item = KWL_ImportRdf($url);
      } else {     /* url, include block */
         $rdf = new RDF;
         $item = $rdf->get_content($url,$max);
      }
      if (!empty($item)) {
         KWL_WriteFile($cache_file, $head . $item . $tail);
         return $item;
      }
   }
   clearstatcache();
   if (file_exists($cache_file)) $content = KWL_ReadFile($cache_file);
   return $content;
}

function KWL_KillCacheFile($item) {
   $cache_file  = KWL_GetConf("G_PATH") ."/logs/cache/". md5($item) .".cache";
   if (file_exists($cache_file)) {
      @unlink($cache_file);
   }
}
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/include/rdf.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

class RDF {
   function export($topic='',$ofile='',$limit=20) {
      global $rdf_lang;
      $CONF = KWL_GetConf();

      if (!empty($ofile)) $this->ofile = "$CONF[G_PATH]/backend/$ofile";
      elseif (empty($CONF['BackendFile'])) $this->ofile = "$CONF[G_PATH]/backend/weblog.rdf";
      else $this->ofile = "$CONF[G_PATH]/backend/$CONF[BackendFile]";

      $sql = "SELECT * FROM T_Stories WHERE Verified = 'Y'";
      if ($topic) $sql .= " AND Topic = $topic";
      $sql .= " ORDER BY Repostamp DESC LIMIT $limit";
      $result = SqlReturnArray($sql);
      if (count($result)) {
         
         $this->lang = $rdf_lang;
         $this->write_rdf($result);

         if(function_exists("iconv")) {
            include_once("$CONF[G_PATH]/include/utf8.inc.php");
            $this->lang = "UTF-8";
            $this->ofile .= ".utf";
            $this->write_rdf($result,1);
         }
         
         unset($result);
      }
   }

   function write_rdf($result,$utf=0) {
      global $rdf_lang;
      $CONF = KWL_GetConf();

      if ($utf) {
         $CONF['SiteName'] = KWL_ConvertUTF8($rdf_lang,$CONF['SiteName']);
         $CONF['SiteSlogan'] = KWL_ConvertUTF8($rdf_lang,$CONF['SiteSlogan']);
      }

      $rdf = "<?xml version=\"1.0\" encoding=\"". $this->lang ."\"?>\n\n".
             "<rss version=\"2.0\">\n\n".
             "<channel>\n".
             "<title>$CONF[SiteName]</title>\n".
             "<link>$CONF[G_URL]</link>\n".
             "<description>$CONF[SiteSlogan]</description>\n".
             "<language>". $this->lang ."</language>\n\n";

      foreach ($result as $A) {
         if ($utf) {
            $A['Heading'] = KWL_ConvertUTF8($rdf_lang,$A['Heading']);
            $A['Author'] = KWL_ConvertUTF8($rdf_lang,$A['Author']);
            $A['Content'] = KWL_ConvertUTF8($rdf_lang,$A['Content']);
         }
         $description = trim(htmlspecialchars(eregi_replace("(\r*)\n","",KWL_ParseContent($A['Content'],3))));
         $rdf .= "<item>\n".
                 "<title>$A[Heading]</title>\n".
                 "<author>$A[Author]</author>\n".
                 "<link>". KWL_MakeStoryLink($A['Rid']) ."</link>\n".
                 "<description>$description</description>\n".
                 "</item>\n\n";
      }
      $rdf .= "</channel>\n</rss>\n";
      if (!KWL_WriteFile($this->ofile,$rdf)) {
         KWL_ErrorLog(_UNABLE_WRITE ." ". $this->ofile);
      }
   }

   function get_rdf($file) {
      $url = @parse_url($file);
      if (isset($url['scheme'])) {
         
         if (!isset($url['port'])) $url['port'] = 80;
         if (!isset($url['query'])) $url['query'] = '';

         $fp = fsockopen($url['host'], 80);
         if ($fp) {
            if (substr(php_uname(), 0, 7) != "Windows") socket_set_timeout($fp, 5);
            fputs($fp, "GET " . $url['path'] . "?" . $url['query'] . " HTTP/1.0\r\n");
            fputs($fp, "HOST: " . $url['host'] . "\r\n\r\n");
            unset($ret);
            $start_at = time();
            $ret = "";
            while(!feof($fp)) {
               $line = fgets($fp, 4096);
               $ret .= trim($line);
               if ((time() - $start_at) == 5) { 
                  /* if we can't retrive file in 5 seconds then give up */
                  return false;
               }
            }
            return $ret;
            fputs($fp,"Connection: close\r\n\r\n");
            fclose($fp);
         } else return false;
      } else {
         /* local file */
         return KWL_ReadFile($file);
      }
   }

   function get_content($file) {
      $url = @parse_url($file);
      if (isset($url['scheme'])) {
         $content = @join ('', @file($file));
         return $content ? $content : false;
      } else {
         /* local file */
         return KWL_ReadFile($file);
      }
   }

   function parse($file,$max_item=10) {
      $dot = KWL_GetConf("dotchar");
      $ret = "";      
      $items = explode("</item>",$file);
      for ($i=0;$i<$max_item;$i++) {
         $link = ereg_replace(".*<link>","",$items[$i]);
         $link = ereg_replace("</link>.*","",$link);
         $title = ereg_replace(".*<title>","",$items[$i]);
         $title = ereg_replace("</title>.*","",$title);
         /*
         $desc = ereg_replace(".*<description>","",$desc[$i]);
         $desc = ereg_replace("</description>.*","",$desc);
         */
         if (strcmp($link,$title)) {
            $trans = get_html_translation_table (HTML_ENTITIES);
            $trans = array_flip ($trans);
            $title = strtr($title, $trans);
            $title = strtr($title, $trans);
            $ret .= $dot ."<a href=\"$link\">". KWL_PrepareHtml($title) ."</a><br />\n";
         }
      }
      return $ret;
   }

   function import($url,$max) {
      return $this->parse($this->get_rdf($url),$max);
   }
} /* end of RDF class */

function KWL_GetContent($A) {
   $file_cache = KWL_GetConf("File_Cache");
   $date       = isset($A['Birthstamp']) ? date("YmdHis",$A['Birthstamp']) : "";
   $updated    = isset($A['Timestamp']) ? date("YmdHis",$A['Timestamp']) : "";
   $time       = date("YmdHis",time());
   $cache      = isset($A['Cache']) ? $A['Cache'] * 60 : "";
   $nextupdate = $updated + $cache;
   $cache_file = isset($A['Rid']) ? md5($A['Rid']) : "";

   if (empty($A['Type'])) return $A['Content'];
   else {

      if ($file_cache && $cache) {
         return KWL_FileCache($A['URL'],$cache,$cache_file,$A['Type'],$A['MaxItem']);
      
      } else {
         
         if ($nextupdate < $time || $date == $updated) {

            if ($A['Type'] == 1) $content = KWL_ImportRdf($A['URL'],$A['MaxItem']);
            else {
               $rdf = new RDF;
               $content = $rdf->get_content($A['URL']);
            }
            if ($A['Cache'] && !empty($content)) {
               $sql 	= "UPDATE T_Blocks SET Content = '". urlencode($content) ."' ".
                       "WHERE Rid = '$A[Rid]'";
               if (!SqlQuery($sql)) KWL_ErrorLog(_UNABLE_RDF);
            }
         
         } else $content = urldecode($A['Content']);
         
         return $content;
      }
   }
}

function KWL_ExportRdf() {
   if (KWL_GetConf("Backend")) {
      $rdf = new RDF;
      $rdf->export();
   }
}

function KWL_ImportRdf($url,$max) {
   $rdf = new RDF;
   return $rdf->import($url,$max);
}

function KWL_FileCache($url,$cache_time,$cache_file,$type=0,$max=10) {
   
	$cache_dir = KWL_GetConf("G_PATH") ."/logs/cache";
   if (!file_exists($cache_dir)) mkdir($cache_dir,0755);
   $cache_file = "$cache_dir/$cache_file".".cache";
   
	$time = split(" ", microtime());
   srand((double)microtime()*1000000);
   $cache_time_rnd = 300 - rand(0, 600);
   $head = "\n<!---- This Block cached at ". date ("m/d h-i a",time()) .
           " ---->\n\n";
   $tail = "\n<!---- End of cached block ---->\n\n";

	clearstatcache();
   if ( (!(file_exists($cache_file))) || ((filectime($cache_file) + $cache_time - $time[1]) + $cache_time_rnd < 0) || (!(filesize($cache_file))) ) {
      
      if ($type == 1) { /* rdf/rss block */
         $item = KWL_ImportRdf($url);
      } else {     /* url, include block */
         $rdf = new RDF;
         $item = $rdf->get_content($url,$max);
      }
      if (!empty($item)) {
         KWL_WriteFile($cache_file, $head . $item . $tail);
         return $item;
      }
   }
   clearstatcache();
   if (file_exists($cache_file)) $content = KWL_ReadFile($cache_file);
   return $content;
}

function KWL_KillCacheFile($item) {
   $cache_file  = KWL_GetConf("G_PATH") ."/logs/cache/". md5($item) .".cache";
   if (file_exists($cache_file)) {
      @unlink($cache_file);
   }
}
?>
